==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/UserSubjectBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UserSubjectBuilder extends UserSubjectFluentImpl<UserSubjectBuilder> implements VisitableBuilder<UserSubject,UserSubjectBuilder>{
  public UserSubjectBuilder() {
    this(false);
  }
  public UserSubjectBuilder(Boolean validationEnabled) {
    this(new UserSubject(), validationEnabled);
  }
  public UserSubjectBuilder(UserSubjectFluent<?> fluent) {
    this(fluent, false);
  }
  public UserSubjectBuilder(UserSubjectFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UserSubject(), validationEnabled);
  }
  public UserSubjectBuilder(UserSubjectFluent<?> fluent,UserSubject instance) {
    this(fluent, instance, false);
  }
  public UserSubjectBuilder(UserSubjectFluent<?> fluent,UserSubject instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UserSubjectBuilder(UserSubject instance) {
    this(instance,false);
  }
  public UserSubjectBuilder(UserSubject instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UserSubjectFluent<?> fluent;
  Boolean validationEnabled;
  public UserSubject build() {
    UserSubject buildable = new UserSubject(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-flowcontrol-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/UserSubjectBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UserSubjectBuilder extends UserSubjectFluent<UserSubjectBuilder> implements VisitableBuilder<UserSubject,UserSubjectBuilder>{
  public UserSubjectBuilder() {
    this(false);
  }
  public UserSubjectBuilder(Boolean validationEnabled) {
    this(new UserSubject(), validationEnabled);
  }
  public UserSubjectBuilder(UserSubjectFluent<?> fluent) {
    this(fluent, false);
  }
  public UserSubjectBuilder(UserSubjectFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UserSubject(), validationEnabled);
  }
  public UserSubjectBuilder(UserSubjectFluent<?> fluent,UserSubject instance) {
    this(fluent, instance, false);
  }
  public UserSubjectBuilder(UserSubjectFluent<?> fluent,UserSubject instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new UserSubject());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UserSubjectBuilder(UserSubject instance) {
    this(instance,false);
  }
  public UserSubjectBuilder(UserSubject instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new UserSubject());

    if (instance != null) {
      this.withName(instance.getName());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UserSubjectFluent<?> fluent;
  Boolean validationEnabled;
  public UserSubject build() {
    UserSubject buildable = new UserSubject(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
